@@ -5,9 +5,8 @@
 #'
 #' @references Ho LST et al. 2016. "Birth(death)/birth-death processes and their computable transition probabilities with statistical applications". In review.
 #'
-#' @docType package
 #' @name MultiBD
 #' @importFrom RcppParallel RcppParallelLibs
 #' @importFrom Rcpp evalCpp
 #' @useDynLib MultiBD
-NULL
+"_PACKAGE"
